@@ -4,18 +4,21 @@
 
 import sys
 
-from opencv_webcam.utils.fonts_opt import fonts_color, info_warning
+from rich.console import Console
+
+from opencv_webcam.utils.fonts_opt import fonts_color
 
 ROOT_PATH = sys.path[0]  # 项目根目录
 
 
 # 检查日志格式
 def is_logSuffix(logName):
+    console = Console()
     suffixList = ["log", "txt", "data"]  # 日志后缀列表
     log_suffix = logName.split(".")[-1]  # 获取日志后缀
     if log_suffix not in suffixList:
         # 判断日志是否符合格式
-        print(f'{info_warning("日志格式不正确！程序结束！")[2]}')
+        console.print("[bold red]日志格式不正确！程序结束！[/bold red]")
         sys.exit()  # 结束程序
 
 
@@ -34,3 +37,10 @@ def log_management(logContent, logName, logSaveMode):
 def date_time_frames(date_time, frames, fdn, fsd):
     f = open(f"{ROOT_PATH}/date_time_frames.csv", "a")  # 创建文件
     f.write(f"{date_time},{frames},{fdn},{fsd}\n")  # 写入
+
+
+# 日志管理（rich版）
+def rich_log(logContent, logName, logSaveMode):
+    report_file = open(f"{ROOT_PATH}/{logName}", logSaveMode)
+    console = Console(file=report_file)
+    console.log(logContent)
