@@ -4,13 +4,15 @@
 
 import sys
 
-from opencv_webcam.utils.fonts_opt import info_warning
+from rich.console import Console
+
+console = Console()
 
 
 # 判断时间格式
 def is_time(preTime):
     if preTime <= 0:
-        print(f'{info_warning("时间格式不正确！程序结束！")[2]}')
+        console.print("[bold red]时间格式不正确！程序结束！[/bold red]")
         sys.exit()
 
 
@@ -23,22 +25,22 @@ def time_format(preTime):
     m = int(m)  # 转整型
 
     if 0 < s < 1:
-        time_str = f"{s:.3f}秒"
+        time_str = f"{s:.3f} 秒"
         return time_str
     elif h == 0 and m == 0 and s >= 1:
-        time_str = f"{s:.3f}秒"
+        time_str = f"{s:.3f} 秒"
         return time_str
     elif h == 0 and m > 0:
-        time_str = f"{m}分{s:.3f}秒"
+        time_str = f"{m} 分{s:.3f} 秒"
         return time_str
     elif h > 0:
         if h >= 24:
             d = int(h / 24)  # 以天为单位
             h2 = h - 24
-            time_str = f"{d}天{h2}时{m}分{s:.3f}秒"
+            time_str = f"{d} 天{h2} 时{m} 分{s:.3f} 秒"
         else:
-            time_str = f"{h}时{m}分{s:.3f}秒"
+            time_str = f"{h} 时{m} 分{s:.3f} 秒"
         return time_str
     else:
-        print(f'{info_warning("时间格式化失败！程序结束！")[2]}')
+        console.print("[bold red]时间格式化失败！程序结束！[/bold red]")
         sys.exit()
